aboutsummaryrefslogtreecommitdiff
path: root/Emby.Naming/Video/Format3DRule.cs
diff options
context:
space:
mode:
authorJoshua M. Boniface <joshua@boniface.me>2020-11-17 10:28:39 -0500
committerGitHub <noreply@github.com>2020-11-17 10:28:39 -0500
commitf6ebdbc45e6dc455b7535dfe341ccba94b2c2a90 (patch)
tree3b42753afda908633880519308fddc25bc249d71 /Emby.Naming/Video/Format3DRule.cs
parentfc3d6278be89b695aa79dc61d7f1226d4d6e441b (diff)
parent04a712ab1d56a29a31e2c4991c16d338348762f4 (diff)
Merge pull request #4456 from martinek-stepan/emby-namig-nullable
Emby.Naming - nullable & code coverage
Diffstat (limited to 'Emby.Naming/Video/Format3DRule.cs')
-rw-r--r--Emby.Naming/Video/Format3DRule.cs22
1 files changed, 17 insertions, 5 deletions
diff --git a/Emby.Naming/Video/Format3DRule.cs b/Emby.Naming/Video/Format3DRule.cs
index 310ec84e8f..e562691df9 100644
--- a/Emby.Naming/Video/Format3DRule.cs
+++ b/Emby.Naming/Video/Format3DRule.cs
@@ -1,19 +1,31 @@
-#pragma warning disable CS1591
-
namespace Emby.Naming.Video
{
+ /// <summary>
+ /// Data holder class for 3D format rule.
+ /// </summary>
public class Format3DRule
{
/// <summary>
+ /// Initializes a new instance of the <see cref="Format3DRule"/> class.
+ /// </summary>
+ /// <param name="token">Token.</param>
+ /// <param name="precedingToken">Token present before current token.</param>
+ public Format3DRule(string token, string? precedingToken = null)
+ {
+ Token = token;
+ PrecedingToken = precedingToken;
+ }
+
+ /// <summary>
/// Gets or sets the token.
/// </summary>
/// <value>The token.</value>
public string Token { get; set; }
/// <summary>
/// Gets or sets the preceeding token.
/// </summary>
- /// <value>The preceeding token.</value>
- public string PreceedingToken { get; set; }
+ /// <value>The preceding token.</value>
+ public string? PrecedingToken { get; set; }
}
}
@@ -1,19 +1,31 @@
public string Token { get; set; }
/// <summary>
- /// Gets or sets the preceeding token.
+ /// Gets or sets the preceding token.
/// </summary>